==> gsystem-0.4.1.tbz: include/G/GSolarsystemCategory.h <==
/***************************************************************************
 *   Copyright (C) 2004 by Raphael Langerhorst                             *
 *   raphael-langerhorst@gmx.at                                            *
 *                                                                         *
 *   Permission is hereby granted, free of charge, to any person obtaining *
 *   a copy of this software and associated documentation files (the       *
 *   "Software"), to deal in the Software without restriction, including   *
 *   without limitation the rights to use, copy, modify, merge, publish,   *
 *   distribute, sublicense, and/or sell copies of the Software, and to    *
 *   permit persons to whom the Software is furnished to do so, subject to *
 *   the following conditions:                                             *
 *                                                                         *
 *   The above copyright notice and this permission notice shall be        *
 *   included in all copies or substantial portions of the Software.       *
 *                                                                         *
 *   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,       *
 *   EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF    *
 *   MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.*
 *   IN NO EVENT SHALL THE AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR     *
 *   OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, *
 *   ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR *
 *   OTHER DEALINGS IN THE SOFTWARE.                                       *
 ***************************************************************************/

#ifndef GBEGSOLARSYSTEMCATEGORY_H
#define GBEGSOLARSYSTEMCATEGORY_H

#include <GDynamicGeneratorCategory.h>

namespace GBE {

/**
\class GSolarsystemCategory GSolarsystemCategory.h
\brief Represents a category for solar system generation.

@author Raphael Langerhorst
*/
class GSolarsystemCategory : public GDynamicGeneratorCategory
{
  public:
    GSolarsystemCategory(double range);

    virtual ~GSolarsystemCategory();
    
    /**
      * This actually creates a form attribute
      * for a new element of this category.
      * Must be implemented by specialisations.
      */
    virtual GCS::GForm* createForm(const GCS::GEnergy& energy, const GCS::GVector3& position, Util::PseudoRNG& rng) const;
    
    /**
      * This actually creates a form attribute
      * for a new element of this category.
      * Must be implemented by specialisations.
      */
    virtual QPtrList<GCS::GAgent> createAgents(const GCS::GEnergy& energy, Util::PseudoRNG& rng) const;
};

};

#endif

==> gsystem-0.5.1_6.tbz: include/G/GSolarsystemCategory.h <==
/***************************************************************************
 *   Copyright (C) 2004 by Raphael Langerhorst                             *
 *   raphael-langerhorst@gmx.at                                            *
 *                                                                         *
 *   Permission is hereby granted, free of charge, to any person obtaining *
 *   a copy of this software and associated documentation files (the       *
 *   "Software"), to deal in the Software without restriction, including   *
 *   without limitation the rights to use, copy, modify, merge, publish,   *
 *   distribute, sublicense, and/or sell copies of the Software, and to    *
 *   permit persons to whom the Software is furnished to do so, subject to *
 *   the following conditions:                                             *
 *                                                                         *
 *   The above copyright notice and this permission notice shall be        *
 *   included in all copies or substantial portions of the Software.       *
 *                                                                         *
 *   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,       *
 *   EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF    *
 *   MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.*
 *   IN NO EVENT SHALL THE AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR     *
 *   OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, *
 *   ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR *
 *   OTHER DEALINGS IN THE SOFTWARE.                                       *
 ***************************************************************************/

#ifndef GBEGSOLARSYSTEMCATEGORY_H
#define GBEGSOLARSYSTEMCATEGORY_H

#include <GDynamicGeneratorCategory.h>

namespace GBE {

/**
\class GSolarsystemCategory GSolarsystemCategory.h
\brief Represents a category for solar system generation.

@author Raphael Langerhorst
*/
class GSolarsystemCategory : public GDynamicGeneratorCategory
{
  public:
    GSolarsystemCategory(double range);

    virtual ~GSolarsystemCategory();
    
    /**
      * This actually creates a form attribute
      * for a new element of this category.
      * Must be implemented by specialisations.
      */
    virtual GCS::GForm* createForm(const GCS::GEnergy& energy, const GCS::GVector3& position, Util::PseudoRNG& rng) const;
    
    /**
      * This actually creates a form attribute
      * for a new element of this category.
      * Must be implemented by specialisations.
      */
    virtual void postProcess(GCS::GElement* element, Util::PseudoRNG& rng) const;
};

};

#endif
